/*
  GetCharState.ino

  This sketch demonstrats how GetCharState function works.

  You have to install MGLCD library Ver.0.34 or later, which controls 
a GLCD module.  MGLCD library can be downloaded at the following web page:

  http://www3.big.or.jp/~schaft/hardware/MGLCD/

  This sketch shows the state of your keypad on your LCD screen.

  This sketch requires a 122X32 MGLCD shield that is introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product_MGLCD_shield_12232_C/index.html

  This sketch also requires a resistive voltage divider keypad.
This sketch assumes that you use the 4X4 keypad introduced in the
following web page:

  http://www3.big.or.jp/~schaft/hardware/product/keypad4X4/page001.html

  This example code is in the public domain.
*/

// include library codes
#include <mglcd.h> // library for LCD
#include <ResKeypad.h> // library for keypad

// variables
#ifdef USBCON // Leonardo
mglcd_serial MGLCD(&Serial1,500000); // define serial LCD
#else // not Leonardo
mglcd_serial MGLCD(&Serial,500000); // define serial LCD
#endif

ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_A); // enable this line if SIDE A of keypad is used
//ResKeypad keypad(A4,16,RESKEYPAD_4X4,RESKEYPAD_4X4_SIDE_B); // enable this line if SIDE B of keypad is used

// functions
void setup()
{
  // initialize LCD
  while(MGLCD.Reset());
} // setup

void loop()
{
  static int LastChar=1000; // character code obtained by last GetCharState() call
  char CurrentChar;

  CurrentChar=keypad.GetCharState();
  if(CurrentChar!=LastChar) {
    MGLCD.Locate(0,0);
    MGLCD.ClearRestOfLine();
    if(CurrentChar=='\0') {
      MGLCD.print("No key is pressed.");
    } else {
      MGLCD.print(CurrentChar);
      MGLCD.print(" is pressed.");
    } // if
    LastChar=CurrentChar;
  } // if
} // loop
